@@ -34,6 +34,7 @@
 //! should provide the other required trait implementations separately.
 //!
 //! * An implementation of the [`Parse`] trait for the underlying type.
+use std::convert::TryInto;
 use std::str::FromStr;
 
 use cssparser::{Parser, Token};
@@ -744,6 +745,12 @@ make_property!(
     "auto" => Auto,
 );
 
+impl Overflow {
+    pub fn overflow_allowed(&self) -> bool {
+        matches!(*self, Overflow::Auto | Overflow::Visible)
+    }
+}
+
 /// One of the three operations for the `paint-order` property; see [`PaintOrder`].
 #[repr(u8)]
 #[derive(Debug, Clone, Copy, Eq, PartialEq)]
