@@ -35,7 +35,7 @@ fn reference_test(path: &Path) {
     setup_language();
     setup_font_map();
 
-    let path_base_name = path.file_stem().unwrap().to_string_lossy().to_owned();
+    let path_base_name = path.file_stem().unwrap().to_string_lossy().into_owned();
     if path_base_name.starts_with("ignore") {
         return;
     }
@@ -160,10 +160,7 @@ fn checked_i32(x: f64) -> i32 {
 fn has_supported_unit(l: &Length) -> bool {
     use rsvg::LengthUnit::*;
 
-    match l.unit {
-        Percent | Px | In | Cm | Mm | Pt | Pc => true,
-        _ => false,
-    }
+    matches!(l.unit, Percent | Px | In | Cm | Mm | Pt | Pc)
 }
 
 const POINTS_PER_INCH: f64 = 72.0;
@@ -758,6 +755,7 @@ mod tests {
     t!(bugs_bug718_rect_negative_rx_ry_svg,                         "bugs/bug718-rect-negative-rx-ry.svg");
     t!(bugs_bug730_font_scaling_svg,                                "bugs/bug730-font-scaling.svg");
     t!(bugs_bug738367_svg,                                          "bugs/bug738367.svg");
+    t!(bugs_bug749415_svg,                                          "bugs/bug749415.svg");
     t!(bugs_bug760180_svg,                                          "bugs/bug760180.svg");
     t!(bugs_bug761175_recursive_masks_svg,                          "bugs/bug761175-recursive-masks.svg");
     t!(bugs_bug761871_reset_reflection_points_svg,                  "bugs/bug761871-reset-reflection-points.svg");
@@ -1197,9 +1195,3 @@ test_svg_reference!(
     "tests/fixtures/reftests/markers-arc-segments.svg",
     "tests/fixtures/reftests/markers-arc-segments-ref.svg"
 );
-
-test_svg_reference!(
-    bug_1121_feimage_embedded_svg,
-    "tests/fixtures/reftests/bugs-reftests/bug1121-feimage-embedded-svg.svg",
-    "tests/fixtures/reftests/bugs-reftests/bug1121-feimage-embedded-svg-ref.svg"
-);
